==> apache-cxf-3.4.5-src.tar.gz: apache-cxf-3.4.5-src/systests/databinding/src/test/java/org/apache/cxf/systest/aegis/AegisJaxWsWsdlNs.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.aegis;

import java.util.List;

import javax.jws.WebParam;
import javax.jws.WebService;

import org.apache.cxf.aegis.type.java5.XmlType;


/**
 *
 */
@WebService(name = "AegisJaxWsWsdlNs", targetNamespace = "http://v1_1_2.rtf2pdf.doc.ws.daisy.marbes.cz")
public interface AegisJaxWsWsdlNs {

    void updateVO(@WebParam(name = "VO")VO vo);

    Integer updateInteger(@WebParam(name = "idInteger") Integer idInteger);


    void updateIntegerList(@WebParam(name = "idIntegerList") List<Integer> idIntegerList);


    @XmlType(name = "VOX", namespace = "http://wo.rtf2pdf.doc.ws.daisy.marbes.cz")
    class VO {

        private String str;

        public String getStr() {
            return str;
        }

        public void setStr(String str) {
            this.str = str;
        }
    }

}

==> apache-cxf-4.0.7-src.tar.gz: apache-cxf-4.0.7-src/systests/databinding/src/test/java/org/apache/cxf/systest/aegis/AegisJaxWsWsdlNs.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.aegis;

import java.util.List;

import jakarta.jws.WebParam;
import jakarta.jws.WebService;
import org.apache.cxf.aegis.type.java5.XmlType;


/**
 *
 */
@WebService(name = "AegisJaxWsWsdlNs", targetNamespace = "http://v1_1_2.rtf2pdf.doc.ws.daisy.marbes.cz")
public interface AegisJaxWsWsdlNs {

    void updateVO(@WebParam(name = "VO")VO vo);

    Integer updateInteger(@WebParam(name = "idInteger") Integer idInteger);


    void updateIntegerList(@WebParam(name = "idIntegerList") List<Integer> idIntegerList);


    @XmlType(name = "VOX", namespace = "http://wo.rtf2pdf.doc.ws.daisy.marbes.cz")
    class VO {

        private String str;

        public String getStr() {
            return str;
        }

        public void setStr(String str) {
            this.str = str;
        }
    }

}
